@@ -2,25 +2,22 @@
 #' A flexible method for displaying simple list elements.
 #' @param content a object of class character
 #' @param badge a object of class logical
-#' @param ... if the badge object is true provide an arguement object of
+#' @param badge_value if the badge object is true provide an arguement object of
 #' class numeric, named badge_value.
 #'
 #' @return a HTML object to be included in the ui section of a shiny app
-#' @importFrom shiny HTML
+#' @import shiny
 #' @seealso \href{http://getbootstrap.com/components/#list-group}{List Group}
 #'
 #' @examples list_item("Howdy Title", badge_value = 27)
 #' @export
-list_item <- function(content, badge = TRUE, ...){
-
-  badge_value = c(...)
+list_item <- function(content, badge = TRUE, badge_value){
 
   if(badge) {
-   HTML(paste0(" <li class='list-group-item'>
-              <span class='badge'>", badge_value, "</span>", content, " </li>"
-      ))
+    tags$li(class = "list-group-item", span(class = "badge", badge_value), content)
+
   } else {
-    HTML(paste0("<li class='list-group-item'>", content, "</li>"))
+    tags$li(class = "list-group-item", content)
   }
 
 }
